#line 1 t/die.t



print "1..1\n";


use Acme::Bleach;
 	 	 	 	 	 	 	 			   	   
 		 		 	 
 	 		  		
	 		 	 	 
 		      
	     			
       	 
   	 			 
				 	   
 	  		 	 
 	 		 	 	
  		  			
 	    	 	
		  	 	  
   	 	   
 	 	  		 
 		 			 	
    		   
		 		    
  	  		 	
			      
	    	  	
	 	  	 		
 	 	  		 
   	 	   
	   	  	 
	  		    
				 		  
 		 	 	  
		     		
	   	 			
 	  	 		 
				 		  
			 		  	
   	  	  
	 	      
 	  	 			
		 		 			
   	 	   
 		   		 
   	 		 	
			 		 	 
		 		    
 			    	
 	  	 		 
		 	  			
	      	 
   	  	  
	 	  		  
  				 		
   		 	 	
  		     
			   	 	
		 	  	 	
	 				 		
  			 		 
     	  	
 				    
   	    	
  	      
  	 	  	 
	  		 			
   	 	   
     			 
 	  			 	
  	 		  	
		 		   	
 			     
 	   	   
	  		   	
       	 
 		 		 	 
  	  	  	
 	  		   
 				 		 
  		 	 	 
 		     	
		   	 		
	 	  	 		
 				 		 
 			 		 	
 			 	   
			 	  		
	 		  	  
 	  		 		
	   	 	  
      			
  	  			 
	  	 		  
			 		   
	 			    
  	  			 
 	   			 
		 				 	
	   	 			
      	  
			  	   
    	  	 
 	 		  		
  		     
 	    	  
	  	 	  	
	    				
 		   		 
	 	  		  
   			   
	 			 	  
	 		 				
 		  			 
		      	
  	    	 
  						 
     	  	
 		 		 		
 				 	 	
  		    	
			 		   
		 	 	  	
	     			
   	 			 
	  	 		 	
			 		  	
		 		    
  	  	   
 		   	 	
		      	
    	 			
 				 	  
  	  		 	
  	 		 	 
	  		  		
	 	    	 
			      
	    		 	
	 	  	 		
  			 		 
	 	  		  
    	  	 
 			    	
		 	  	  
 		 	 			
		 		 			
   	 	   
     			 
 	  			 	
  	 		  	
		 		   	
 			     
 	  			  
	  				 	
	 		 	 		
      	  
	   		  	
		  	  		
 			   	 
	    

